@@ -1,7 +1,6 @@
 from pathlib import Path
 from subprocess import run
 
-__all__ = []
 ROOT = Path(__file__).resolve().parent
 
 
@@ -17,7 +16,7 @@ def generate_map(files: list[Path]):
 
 def generate_mo(maps: list[tuple[Path, Path]]):
     for i, j in maps:
-        command = f'msgfmt "{i}" -o "{j}"'
+        command = f'msgfmt --check -o "{j}" "{i}"'
         print(run(command, shell=True, text=True))
 
 
