@@ -6,6 +6,8 @@ from .model import (
 )
 from .recorder import DataRecorder
 from .recorder import IDRecorder
+from .recorder import MapRecorder
+from .mapping import Mapping
 from .settings import Settings
 from .static import (
     VERSION_MAJOR,
@@ -26,15 +28,14 @@ from .static import (
     HEADERS,
     PROJECT,
     USERAGENT,
-    SEC_CH_UA,
-    SEC_CH_UA_PLATFORM,
     FILE_SIGNATURES,
     FILE_SIGNATURES_LENGTH,
     MAX_WORKERS,
+    __VERSION__,
 )
 from .tools import (
     retry,
     logging,
     sleep_time,
+    retry_limited,
 )
-from .translator import Translate
