@@ -1,4 +1,6 @@
 import asyncio
+from concurrent.futures import ProcessPoolExecutor
+
 from ...utiles.img_host import ImgHost
 import time
 from dataclasses import dataclass
@@ -13,8 +15,9 @@ from ...types import (
     ImageParseResult,
     Video,
     Subtitles,
-    DownloadResult,
+    DownloadResult, ParseError,
 )
+EXC = ProcessPoolExecutor()
 
 
 class YtParser(Parser):
@@ -37,8 +40,14 @@ class YtParser(Parser):
             return YtVideoParseResult(video=video_info.url, **_d)
 
     async def _parse(self, url, params=None) -> "YtVideoInfo":
-        with YoutubeDL(params or self.params) as ydl:
-            dl = ydl.extract_info(url, download=False)
+        loop = asyncio.get_running_loop()
+        try:
+            dl = await asyncio.wait_for(
+                loop.run_in_executor(EXC, self._extract_info, url, params),
+                timeout=30
+            )
+        except asyncio.TimeoutError:
+            raise ParseError("解析视频信息超时")
         if dl.get("_type"):
             dl = dl["entries"][0]
             url = dl["webpage_url"]
@@ -55,7 +64,9 @@ class YtParser(Parser):
             duration=duration,
             url=url,
         )
-
+    def _extract_info(self, url, params=None):
+        with YoutubeDL(params or self.params) as ydl:
+            return ydl.extract_info(url, download=False)
     # def hook(self, d):
     #     current = d.get("downloaded_bytes", 0)
     #     total = d.get("total_bytes", 0)
@@ -69,7 +80,7 @@ class YtParser(Parser):
         params = {
             "format": "mp4+bestvideo[height<=1080]+bestaudio",
             "quiet": True,  # 不输出日志
-            "writethumbnail": True,  # 下载缩略图
+            # "writethumbnail": True,  # 下载缩略图
             # "postprocessors": [
             #     {
             #         "key": "FFmpegVideoConvertor",
@@ -104,7 +115,6 @@ class YtVideoParseResult(VideoParseResult):
         path: str | Path = None,
         callback: Callable = None,
         callback_args: tuple = (),
-        proxies: dict | str = None,
         config: DownloadConfig = DownloadConfig(),
     ) -> DownloadResult:
         """下载视频"""
@@ -136,22 +146,38 @@ class YtVideoParseResult(VideoParseResult):
         if callback:
             await callback(0, 0, text, *callback_args)
 
-        with YoutubeDL(yto) as ydl:
-            await asyncio.to_thread(ydl.download, [self.media.path])
+        loop = asyncio.get_running_loop()
+        try:
+            await asyncio.wait_for(
+                loop.run_in_executor(EXC, self._download, yto, [self.media.path]),
+                timeout=300
+            )
+        except asyncio.TimeoutError:
+            raise ParseError("下载超时")
 
-        video_path = (v := list(dir_.glob("*.mp4")) or list(dir_.glob("*.mkv"))) and v[
-            0
-        ]
+        video_path = (
+            v := list(dir_.glob("*.mp4"))
+            or list(dir_.glob("*.mkv"))
+            or list(dir_.glob("*.webm"))
+        ) and v[0]
         subtitles = (v := list(dir_.glob("*.ttml"))) and Subtitles().parse(v[0])
-        thumb = (
-            v := list(dir_.glob("*.webp")) or list(dir_.glob("*.jpg"))
-        ) and await ImgHost().catbox(v[0])
+        try:
+            thumb = await ImgHost().litterbox(self.dl.thumbnail)
+        except:
+            thumb = None
+        # thumb = (
+        #     v := list(dir_.glob("*.webp")) or list(dir_.glob("*.jpg"))
+        # ) and await ImgHost().catbox(v[0])
         return DownloadResult(
             self,
             Video(path=str(video_path), subtitles=subtitles, thumb_url=thumb),
             dir_,
         )
 
+    @staticmethod
+    def _download(yto, urls: list[str]):
+        with YoutubeDL(yto) as ydl:
+            return ydl.download(urls)
 
 class YtImageParseResult(ImageParseResult):
     def __init__(
